summaryrefslogtreecommitdiffstats
path: root/klinkstatus/src/global.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'klinkstatus/src/global.cpp')
-rw-r--r--klinkstatus/src/global.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/klinkstatus/src/global.cpp b/klinkstatus/src/global.cpp
index f572aacb..66dbf30f 100644
--- a/klinkstatus/src/global.cpp
+++ b/klinkstatus/src/global.cpp
@@ -144,20 +144,20 @@ void Global::openQuanta(TQStringList const& args)
void Global::execCommand(TQString const& command)
{
//We create a KProcess that executes the "ps" *nix command to get the PIDs of the
//other instances of quanta actually running
- self()->process_PS_ = new KProcess();
+ self()->process_PS_ = new TDEProcess();
*(self()->process_PS_) << TQStringList::split(" ",command);
- connect( self()->process_PS_, TQT_SIGNAL(receivedStdout(KProcess*,char*,int)),
- self(), TQT_SLOT(slotGetScriptOutput(KProcess*,char*,int)));
- connect( self()->process_PS_, TQT_SIGNAL(receivedStderr(KProcess*,char*,int)),
- self(), TQT_SLOT(slotGetScriptError(KProcess*,char*,int)));
- connect( self()->process_PS_, TQT_SIGNAL(processExited(KProcess*)),
- self(), TQT_SLOT(slotProcessExited(KProcess*)));
+ connect( self()->process_PS_, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+ self(), TQT_SLOT(slotGetScriptOutput(TDEProcess*,char*,int)));
+ connect( self()->process_PS_, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+ self(), TQT_SLOT(slotGetScriptError(TDEProcess*,char*,int)));
+ connect( self()->process_PS_, TQT_SIGNAL(processExited(TDEProcess*)),
+ self(), TQT_SLOT(slotProcessExited(TDEProcess*)));
- //if KProcess fails I think a message box is needed... I will fix it
- if (!self()->process_PS_->start(KProcess::NotifyOnExit,KProcess::All))
+ //if TDEProcess fails I think a message box is needed... I will fix it
+ if (!self()->process_PS_->start(TDEProcess::NotifyOnExit,TDEProcess::All))
kdError() << "Failed to query for running KLinkStatus instances!" << endl;
//TODO: Replace the above error with a real messagebox after the message freeze is over
else
@@ -173,21 +173,21 @@ void Global::execCommand(TQString const& command)
}
}
-void Global::slotGetScriptOutput(KProcess* /*process*/, char* buf, int buflen)
+void Global::slotGetScriptOutput(TDEProcess* /*process*/, char* buf, int buflen)
{
TQCString tmp( buf, buflen + 1 );
script_output_ = TQString();
script_output_ = TQString::fromLocal8Bit(tmp).remove(" ");
}
-void Global::slotGetScriptError(KProcess*, char* buf, int buflen)
+void Global::slotGetScriptError(TDEProcess*, char* buf, int buflen)
{
//TODO: Implement some error handling?
Q_UNUSED(buf);
Q_UNUSED(buflen);
}
-void Global::slotProcessExited(KProcess*)
+void Global::slotProcessExited(TDEProcess*)
{
slotProcessTimeout();
}
@@ -144,20 +144,20 @@ void Global::openQuanta(TQStringList const& args)
void Global::execCommand(TQString const& command)
{
- //We create a KProcess that executes the "ps" *nix command to get the PIDs of the
+ //We create a TDEProcess that executes the "ps" *nix command to get the PIDs of the
//other instances of quanta actually running